Row

Struct Row 

pub struct Row<'a, T: 'a> { /* private fields */ }
Row of a matrix.

This struct points to a slice making up a row in a matrix. You can deref this struct to retrieve a MatrixSlice of the row.

Example

use rulinalg::matrix::BaseMatrix;

let mat = matrix![1.0, 2.0;
                  3.0, 4.0];

let row = mat.row(1);
assert_eq!((*row + 2.0).sum(), 11.0);

Implementations

Source

impl<'a, T: 'a> Row<'a, T>

pub fn raw_slice(&self) -> &'a [T]

Returns the row as a slice.